==> jinrousiki-3.1.0.zip: jinrousiki-3.1.0/include/controller/game_log_class.php <==
<?php
//-- GameLog 出力クラス --//
class GameLog {
  //実行
  public static function Execute() {
    self::Load();
    self::Certify();
    self::Check();
    self::Output();
  }

  //データロード
  private static function Load() {
    Loader::LoadRequest('game_log');
    DB::Connect();
    Session::Login();

    DB::LoadRoom();
    DB::$ROOM->SetFlag(RoomMode::LOG);
    DB::LoadUser();
    DB::LoadSelf();
  }

  //認証 (死者 / ゲーム終了後)
  private static function Certify() {
    if (DB::$SELF->IsDead() || DB::$ROOM->IsFinished()) return;
    HTML::OutputResult(GameLogMessage::CERTIFY, GameLogMessage::CERTIFY . Message::TOP);
  }

  //シーンチェック
  private static function Check() {
    switch (RQ::Get()->scene) {
    case RoomScene::AFTER:
    case RoomScene::HEAVEN:
      if (! DB::$ROOM->IsFinished()) { //霊界・ゲーム終了後はゲーム終了後のみ
	self::OutputResult(GameLogMessage::PLAYING);
      }
      break;

    default:
      if (DB::$ROOM->date < RQ::Get()->date ||
	  (DB::$ROOM->IsDate(RQ::Get()->date) &&
	   (DB::$ROOM->IsDay() || DB::$ROOM->scene == RQ::Get()->scene))) { //未来判定
	self::OutputResult(GameLogMessage::FUTURE);
      }
      DB::$ROOM->last_date = DB::$ROOM->date;
      DB::$ROOM->date      = RQ::Get()->date;
      DB::$ROOM->SetScene(RQ::Get()->scene);
      DB::$USER->SetEvent(true);
      break;
    }
  }

  //出力
  private static function Output() {
    GameHTML::OutputHeader('game_log');
    self::OutputHeader();
    if (RQ::Get()->scene == RoomScene::HEAVEN) {
      DB::$ROOM->SetFlag(RoomMode::HEAVEN); //念のためセット
      Talk::OutputHeaven();
    } else {
      self::OutputAbility();
      Talk::Output();

      if (DB::$ROOM->IsPlaying()) { //プレイ中は投票結果・遺言・死者を表示
	GameHTML::OutputLastWords();
	GameHTML::OutputDead();
      } elseif (DB::$ROOM->IsAfterGame()) {
	GameHTML::OutputLastWords(true); //遺言 (昼終了時限定)
      }

      if (DB::$ROOM->IsNight()) GameHTML::OutputVote();
    }
    HTML::OutputFooter(true);
  }

  //ヘッダ出力
  private static function OutputHeader() {
    switch (RQ::Get()->scene) {
    case RoomScene::BEFORE:
      $scene = GameLogMessage::BEFOREGAME;
      break;

    case RoomScene::DAY:
      $scene = sprintf(GameLogMessage::DAY, DB::$ROOM->date);
      break;

    case RoomScene::NIGHT:
      $scene = sprintf(GameLogMessage::NIGHT, DB::$ROOM->date);
      break;

    case RoomScene::AFTER:
      $scene = sprintf(GameLogMessage::AFTERGAME, DB::$ROOM->date);
      break;

    case RoomScene::HEAVEN:
      $scene = GameLogMessage::HEAVEN;
      break;
    }
    HTML::OutputHeaderTitle(GameLogMessage::HEADER . ' ' . $scene);
  }

  //能力発動ログ出力 (管理者限定)
  private static function OutputAbility() {
    if (RQ::Get()->user_no > 0 && DB::$SELF->IsDummyBoy() && ! DB::$ROOM->IsOption('gm_login')) {
      Loader::LoadFile('image_class');
      DB::LoadSelf(RQ::Get()->user_no);
      DB::$SELF->live = UserLive::LIVE;
      RoleHTML::OutputAbility();
    }
  }

  //エラー処理
  private static function OutputResult($str) {
    HTML::OutputResult(GameLogMessage::INPUT, GameLogMessage::INPUT . $str);
  }
}

==> jinrousiki-4.0.0.zip: jinrousiki-4.0.0/include/controller/game_log_class.php <==
<?php
//◆文字化け抑制◆//
//-- GameLog コントローラー --//
final class GameLogController extends JinrouController {
  protected static function Load() {
    Loader::LoadRequest('game_log');
    DB::Connect();
    Session::Login();

    DB::LoadRoom();
    DB::$ROOM->SetFlag(RoomMode::LOG);
    DB::LoadUser();
    DB::LoadSelf();
    self::Certify();
    self::Validate();
  }

  protected static function Output() {
    GameHTML::OutputHeader('game_log');
    self::OutputHeader();
    if (RQ::Get()->scene == RoomScene::HEAVEN) {
      DB::$ROOM->SetFlag(RoomMode::HEAVEN); //念のためセット
      Talk::OutputHeaven();
    } else {
      self::OutputAbility();
      Talk::Output();

      if (DB::$ROOM->IsPlaying()) { //プレイ中は投票結果・遺言・死者を表示
	GameHTML::OutputLastWords();
	GameHTML::OutputDead();
      } elseif (DB::$ROOM->IsAfterGame()) {
	GameHTML::OutputLastWords(true); //遺言 (昼終了時限定)
      }

      if (DB::$ROOM->IsNight()) {
	GameHTML::OutputVote();
      }
    }
    HTML::OutputFooter(true);
  }

  //認証 (死者 or ゲーム終了後のみ)
  private static function Certify() {
    if (DB::$SELF->IsDead() || DB::$ROOM->IsFinished()) return;
    HTML::OutputResult(GameLogMessage::CERTIFY, GameLogMessage::CERTIFY . Message::TOP);
  }

  //シーンチェック
  private static function Validate() {
    switch (RQ::Get()->scene) {
    case RoomScene::AFTER:
    case RoomScene::HEAVEN:
      if (false === DB::$ROOM->IsFinished()) { //霊界・ゲーム終了後はゲーム終了後のみ
	self::OutputError(GameLogMessage::PLAYING);
      }
      break;

    default:
      if (DB::$ROOM->date < RQ::Get()->date ||
	  (DB::$ROOM->IsDate(RQ::Get()->date) &&
	   (DB::$ROOM->IsDay() || DB::$ROOM->scene == RQ::Get()->scene))) { //未来判定
	self::OutputError(GameLogMessage::FUTURE);
      }
      DB::$ROOM->last_date = DB::$ROOM->date;
      DB::$ROOM->date      = RQ::Get()->date;
      DB::$ROOM->SetScene(RQ::Get()->scene);
      DB::$USER->SetEvent(true);
      break;
    }
  }

  //ヘッダ出力
  private static function OutputHeader() {
    switch (RQ::Get()->scene) {
    case RoomScene::BEFORE:
      $scene = GameLogMessage::BEFOREGAME;
      break;

    case RoomScene::DAY:
      $scene = sprintf(GameLogMessage::DAY, DB::$ROOM->date);
      break;

    case RoomScene::NIGHT:
      $scene = sprintf(GameLogMessage::NIGHT, DB::$ROOM->date);
      break;

    case RoomScene::AFTER:
      $scene = sprintf(GameLogMessage::AFTERGAME, DB::$ROOM->date);
      break;

    case RoomScene::HEAVEN:
      $scene = GameLogMessage::HEAVEN;
      break;
    }
    HTML::OutputHeaderTitle(GameLogMessage::HEADER . ' ' . $scene);
  }

  //能力発動ログ出力 (管理者限定)
  private static function OutputAbility() {
    if (RQ::Get()->user_no > 0 && DB::$SELF->IsDummyBoy() &&
	false === DB::$ROOM->IsOption('gm_login')) {
      Loader::LoadFile('image_class');
      DB::LoadSelf(RQ::Get()->user_no);
      DB::$SELF->live = UserLive::LIVE;
      RoleHTML::OutputAbility();
    }
  }

  //エラー処理
  private static function OutputError($str) {
    HTML::OutputResult(GameLogMessage::INPUT, GameLogMessage::INPUT . $str);
  }
}
